(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68484,       2170]*)
(*NotebookOutlinePosition[    114490,       3747]*)
(*  CellTagsIndexPosition[    112850,       3710]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Chapter 2", "Subtitle"],

Cell[CellGroupData[{

Cell["Mathematical Methods", "Title",
  CounterAssignments->{{"Title", 1}}],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Motivation"
}], "Section"],

Cell[TextData[{
  "Actually enough already has been written about the solving methods of \
linear equations (e.g. ",
  ButtonBox["[Metz1996]",
    ButtonData:>{"Literatur.nb", "[Metz1996]"},
    ButtonStyle->"Hyperlink"],
  ", section 3.5, p. 23-26). Nevertheless in this chapter the application of \
Fourier and Laplace techniques for generating propagators and Green's \
functions is indicated shortly and extended."
}], "Text"],

Cell[TextData[{
  "The main reason to this chapter is the elucidation of the applicability of \
Dirac's ",
  StyleBox["delta function",
    FontSlant->"Italic"],
  " as an analytical function being consistent due to function theory. \
Further more is to be shown, how by use of it also more complicated linear \
differential equations (also fractional) can be solved eventually, especially \
concerning the calculation of momenta."
}], "Text"],

Cell[TextData[{
  "The results being presented here give a fundamental theoretical extension, \
without which a consistent realization of the software package ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " would not have been possible. The following elaboration presents the \
basics in such a way, that knowledge of the software package indeed is \
useful, but not necessary to be able to follow the content."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Dirac's Delta Function"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Singular Integrals"
}], "Subsection"],

Cell["\<\
If a definite integral diverges for a certain choice of the \
parameters, then thoroughly it makes sense to present the whole solution in a \
possibly united form.\
\>", "Text"],

Cell["\<\
For the presentation of these potential singular integration \
results also among others Dirac's delta function is suitable. Nevertheless \
yet today some mathematicians meet it with suspicion, because the transition \
into the singularity is done non-continually.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Fourier Transformation of Number One"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Properties of Fourier Transformation"
}], "Subsubsection"],

Cell[TextData[{
  "The Fourier transformation of a constant can be reduced to the one of \
number one. The Fourier integral itself reads concerning this elaboration and \
at the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 3.0 (There are also deviations from this in other elaborations \
concerning the multiplicator and the sign, e.g. at ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0):"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\_x\%k[f[x]] := 
      \[Integral]\_\(-\[Infinity]\)\%\[Infinity] Exp[\(+\[ImaginaryI]\)\ k\ x]
             f[x] \(\[DifferentialD]x.\)\)], "NumberedEquation",
  CellTags->"Fourier-Transformation"],

Cell[TextData[{
  "With symmetrical functions ",
  Cell[BoxData[
      \(TraditionalForm\`f[\(-x\)] \[Equal] f[x]\)]],
  " the Fourier transformation can convert to the cosine transformation:"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\&c\_x\%k[f[x]] := 
      \[Integral]\_0\%\[Infinity] Cos[k\ x] f[x] \(\[DifferentialD]x.\)\)], 
  "NumberedEquation",
  CellTags->"Cosinus-Transformation"],

Cell["\<\
Further properties of the Fourier transformations are listed in \
appendix B of this elaboration.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Application of the Mean Value Sentence"
}], "Subsubsection"],

Cell[TextData[{
  "The Fourier transformation of number one leads from equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Transformation"],
  ") to the double of equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cosinus-Transformation"],
  "), where now a parametric integral is to be solved:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[ScriptCapitalF]\_x\%k[1]\), "=", 
      RowBox[{\(2  \[ScriptCapitalF]\&c\_x\%k[1]\), "=", 
        RowBox[{
        \(2 \(\[Integral]\_0\%\[Infinity] Cos[k\ x] \[DifferentialD]x\)\), 
          "=", 
          RowBox[{"{", GridBox[{
                {\(\[Infinity]\ \ \ \ \ \ \ \ \ \ \ \ \ \ k = 0, \)},
                {\(\ 0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ k \[NotEqual] 0.\)}
                }]}]}]}]}]], "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins"],

Cell[TextData[{
  "The calculated results can be understood well via the mean value sentence \
(",
  ButtonBox["[Rot1954]",
    ButtonData:>{"Literatur.nb", "[Rot1954]"},
    ButtonStyle->"Hyperlink"],
  ", II. \[Section]13.9, p. 86-87), because for ",
  Cell[BoxData[
      \(TraditionalForm\`k \[NotEqual] 0\)]],
  " the mean value of infinitely many periods of the cosine function is \
determined. The integral of finitely many cosine periods anyway gives zero."
}], "Text"],

Cell[TextData[{
  "Other accesses to the integral (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Transformation der Eins"],
  ") result indeterminated terms. The formulation of an unequivocal result \
indeed is possible, but not accepted everywhere."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Definition of the Delta Function due to Dirac"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "P. A. M. Dirac now gives a function, that has got the properties of \
equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Transformation der Eins"],
  ") and is able to give back number one by inverse Fourier transformation. \
This delta function is defined by the following three assumptions (",
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  ", p. 625-626):"
}], "Text"],

Cell[BoxData[
    \(\(\[Delta][x] = 0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ x \[NotEqual] 0, \)\)],
   "NumberedEquation",
  CellTags->"1.Delta-Axiom"],

Cell[BoxData[
    \(\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]x\ 
          \[Delta][x] = 1, \)\)], "NumberedEquation",
  CellTags->"2.Delta-Axiom"],

Cell[BoxData[
    \(\[Delta][x] = \(\[Delta][\(|x | \)].\)\)], "NumberedEquation",
  CellTags->"3.Delta-Axiom"],

Cell[TextData[{
  "In the original elaboration of Dirac there is a misprint with the \
formulation of definition (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Delta-Axiom"],
  "), which unfortunately intensifies the possibilities of critizism to his \
publication."
}], "Text"],

Cell[TextData[{
  "A consequence being consistent due to function theory results from the \
definitions (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "1.Delta-Axiom"],
  ") to (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "3.Delta-Axiom"],
  ") in a complex phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi]\)]],
  " of the integral depending on the direction of the integration path, which \
is presented here already in a possibly general useful presentation:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\(Exp[\[ImaginaryI]\ \[CurlyPhi]]\)\[Delta][x] 
          \[DifferentialD]x = 
      \(\((Exp[\[ImaginaryI]\ \[CurlyPhi]]\/2)\).\)\)], "NumberedEquation",
  CellTags->"Praktisches Delta-Integral"],

Cell[TextData[{
  "It should be mentioned, that already Dirac in his elaboration discusses \
the delta function having a complex argument (",
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  ", eq. (1), p. 626); this result as yet is fundamental:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[x] \[Delta][a - x] 
          \[DifferentialD]x = \(f[a].\)\)], "NumberedEquation",
  CellTags->"Delta-Theorem"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Determination of the Multiplicator of the Fourier Transformation"
}], "Subsubsection"],

Cell[TextData[{
  "Because the delta function plays an important role with the solution \
theory of linear equations, a sensible convention of mathematics consists in \
setting the Fourier transform of the delta function to number one. By the \
above given definition of the Fourier transformation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Transformation"],
  ") in connection to equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Theorem"],
  ") results the following:"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\_x\%k[\[Delta][x]] = 
      \(2  \[ScriptCapitalF]\&c\_x\%k[\[Delta][x]] = 
        \(2 \(\[Integral]\_0\%\[Infinity] Cos[k\ x] \[Delta][x] 
                \[DifferentialD]x\) = 1.\)\)\)], "NumberedEquation",
  CellTags->"Fourier-Transformation der Delta-Funktion"],

Cell[TextData[{
  "Therefore the Fourier transform of number one is proportional to Dirac's \
delta function. The multiplicator of proportionality results from the inverse \
Fourier transformation by use of the self-inversity of the cosine \
transformation and equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  "):"
}], "Text",
  PageBreakAbove->True],

Cell[BoxData[
    \(\((\[ScriptCapitalF]\^\(-1\))\)\_k\%x[2  \[Pi]\ \[Delta][k]] = 
      \(\(1\/\[Pi]\) \[ScriptCapitalF]\&c\_k\%x[2\ \[Pi]\ \[Delta][k]] = 
        \(\(\(2  \[Pi]\)\/\[Pi]\) 
            \(\[Integral]\_0\%\[Infinity] Cos[k\ x] \[Delta][k] 
                \[DifferentialD]k\) = 1.\)\)\)], "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"],

Cell[TextData[{
  "Thus the delta function gives clearness, if the multiplicators of the \
Fourier transformation are determined according to definition (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Transformation"],
  "). This clearness at the latest is necessary with the use of computer \
algebra."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Mellin Transformation of Number One"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Result from Fourier Transformation"
}], "Subsubsection"],

Cell[TextData[{
  "Already Mellin directs to a close relationship between Fourier and Mellin \
transformation (",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]8, p. 324). An explicit carrying-out of the corresponding \
transformations results by use of the substitutions ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \(-Log[x]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta] \[Rule] \[ImaginaryI]\ z\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(f[x] = 
      \(f[\[ExponentialE]\^\(-t\)] = 
        \(\(1\/\(2  \[Pi]\)\) 
            \(\[Integral]\_\(-
                  \[Infinity]\)\%\[Infinity]\( 
                    \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Zeta]\ t\)\) 
                \[DifferentialD]\[Zeta] 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[
                      \[ExponentialE]\^\(-t\)]\ 
                    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Zeta]\ t\)\) 
                    \[DifferentialD]t\)\) = \n\t\t\t\n
          \(\( = \(\(-\[ImaginaryI]\)\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \[Integral]\_\(-
                    \[Infinity]\)\%\[Infinity]\( x
                      \^\(\[ImaginaryI]\ \[Zeta]\)\) \[DifferentialD]\[Zeta] 
                  \(\[Integral]\_0\%\[Infinity] f[x]\ 
                      \(x\^\(\(-\[ImaginaryI]\)\ \[Zeta] - 1\)\) 
                      \[DifferentialD]x\)\) = \n\t\t\t\t\t\n
            \( = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \[Integral]\_\(\(-\[ImaginaryI]\)\ 
                    \[Infinity]\)\%\(\[ImaginaryI]\ 
                    \[Infinity]\)\(x\^\(-z\)\) \[DifferentialD]z 
                  \(\[Integral]\_0\%\[Infinity] f[x]\ \(x\^\(z - 1\)\) 
                      \(\[DifferentialD]x.\)\)\)\)\)\)\)], "NumberedEquation",\

  CellTags->"Fourier-Mellin-Transformationen"],

Cell[TextData[{
  "The provisional results of these transformations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Mellin-Transformationen"],
  ") result by the residuum (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", 
  "Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"],
  ") and definition (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "3.Delta-Axiom"],
  ") the Mellin transform of number one, at which calculation the author was \
assisted kindly by Professor Dr. W. Wonneberger (Ulm):"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\) \[DifferentialD]x = 
      \(2  \[Pi]\ \[Delta][\[Zeta]] = 
        \(2  \[Pi]\ \[Delta][\[ImaginaryI]\ z] = 
          2  \[Pi]\ \(\[Delta][z].\)\)\)\)], "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Mellin Residuum of the Delta Function"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The inverse Mellin transform of the result (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Transformation der Eins"],
  ") yields by the integral (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") according to the equations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Mellin-Transformationen"],
  "):"
}], "Text"],

Cell[BoxData[
    \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(\(-\[ImaginaryI]\)\ \[Infinity]\)\%\(\[ImaginaryI]\ 
              \[Infinity]\)\[Delta][z]\ \(x\^\(-z\)\) \[DifferentialD]z\) = 
      \(\((1\/\(2\ \[Pi]\))\).\)\)], "NumberedEquation",
  CellTags->"Mellin-Residuum der Delta-Funktion"],

Cell[TextData[{
  "Therefore in the meaning of Mellin transformation even the residuum of the \
delta function is unequivocal in spite of the direction dependency of the \
integral (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  "). The calculation of this ",
  StyleBox["Mellin residuum",
    FontSlant->"Italic"],
  " can fail by the formulae, that otherwise are valid for continuously \
attainable singularities."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Independent Confirmation"
}], "Subsubsection"],

Cell[TextData[{
  "For not to establish inconsistencies, there is great value in getting a \
new result by several derivations. Therefore the Mellin transform of number \
one (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Transformation der Eins"],
  ") now is to be confirmed on an independent way. The integral itself ranks \
as being divergent for all real ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`z \[NotEqual] 1\)]],
  " the Mellin transform of number one yields within the integration \
intervals ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] x \[LessEqual] 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] x \[LessEqual] \[Infinity]\)]],
  " both of the following functions, which can be continued analytically on \
their part:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\) \[DifferentialD]x = 
      \(\[Integral]\_0\%1\( x\^\(z - 1\)\) \[DifferentialD]x + 
          \[Integral]\_1\%\[Infinity]\( x\^\(z - 1\)\) \[DifferentialD]x = 
        1\/z - 1\/z\), \n\nRe[z] > 0\ \ and\ \ Re[z] < 0.\)], 
  "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 1.Teil"],

Cell[TextData[{
  "The word \"",
  Cell[BoxData[
      \(TraditionalForm\`and\)]],
  "\" in the result (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", 
  "Mellin-Transformation der Eins explizit 1.Teil"],
  ") confuses again and again, because indeed the nearby fallacy is \
nourished, that the real part of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " would be obliged to be positive and negative ",
  StyleBox["simultaneously",
    FontSlant->"Italic"],
  ", but indeed it elucidates, that for the present there are two different \
validity intervals to be distinguished ",
  StyleBox["simultaneously",
    FontSlant->"Italic"],
  ", before each analytical continuation of the partial results takes place. \
The given integral already caused difficulties to the author concerning his \
diploma thesis (",
  ButtonBox["[S\[UDoubleDot]d1997]",
    ButtonData:>{"Literatur.nb", "[Sued1997]"},
    ButtonStyle->"Hyperlink"],
  ", sections 3.1.4.3 and 6.3.3, p. 42-44 and 93-94), which are solved now \
even for computer algebra."
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] 0\)]],
  " the Mellin transform of number one yields logarithmic singularities, \
which cannot be removed by an analytical continuation of convergent partial \
integrals:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\[DifferentialD]x\/x = 
      Log[x]\(|\_0\%\[Infinity]\)\(\( = \[Infinity] + \[Infinity]\) = 
        \(\[Infinity].\)\)\)], "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 2.Teil"],

Cell[TextData[{
  "Since Mellin transformation constantly yields results without poles \
according to the established function and integral theory, always an \
analytical continuation within Mellin space into the singularities of the \
result is necessary, that inverse Mellin transform can take place via the \
residual sentence by use of these singularities (cmp. ",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", validity intervals of eq. (40), p. 316)."
}], "Text",
  PageBreakAbove->True],

Cell["\<\
When implementing Mellin transformation to computer algebra, the \
author very soon realized this property, because the singularities of the \
residual calculation always were located beyond the calculated validity \
interval of the Mellin transform.\
\>", "Text"],

Cell[TextData[{
  "As a retaining rule generally results, that the ",
  StyleBox["validity intervals of Mellin space",
    FontSlant->"Italic"],
  " indeed are correct for integral convergence, but ",
  StyleBox["are to be ignored",
    FontSlant->"Italic"],
  " otherwise! Maybe especially this property of Mellin transformation keeps \
many mathematicians from getting down to the possibilities of this \
transformation."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Consequences from the Sentence of Mellin"
}], "Subsubsection"],

Cell[TextData[{
  "The sentence of Mellin calls a pair of function and Mellin transform to be \
reciprocal functions and tells (",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", S. 323):"
}], "Text"],

Cell["\<\
\"One of two reciprocal functions can be identical
to null just if also the other one is equal to zero only.\"\
\>", "Text",
  TextAlignment->Center,
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[TextData[{
  "In application to the just now by use of all calculation rules \
successfully gotten results (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Transformation der Eins"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Residuum der Delta-Funktion"],
  ") the sentence of Mellin is the ",
  StyleBox["proof of existence to Dirac's delta function",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "The author thinks the sentence of Mellin to be one of the most difficult \
to understand and most unknown sentences of analytical mathematics. For its \
understanding an additional lecture ",
  StyleBox["function theory III",
    FontSlant->"Italic"],
  " would be necessary."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". The Momenta of the Delta Function"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Connection Between Mellin Transformation and Momenta"
}], "Subsubsection"],

Cell[TextData[{
  "The momentum integrals of order ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " of a distribution function ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " are defined the following (",
  ButtonBox["[BrS1987]",
    ButtonData:>{"Literatur.nb", "[BrS1987]"},
    ButtonStyle->"Hyperlink"],
  ", section 5.1.3, p. 667 top):"
}], "Text"],

Cell[BoxData[
    \(\(x\^m\)\&_ = \(\( < \((x\^m)\) > \)\  = \ \( < \((x\^m)\)\)\), 
    \(f[x] > \)\  := 
      \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( x\^m\) f[x] 
          \(\[DifferentialD]x.\)\)], "NumberedEquation",
  CellTags->"Momente"],

Cell[TextData[{
  "The Mellin transformation is given by the following integral (",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]8, eq. (51), p. 319):"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalM]\_x\%z[f[x]] := 
      \[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\) f[x] 
          \(\[DifferentialD]x.\)\)], "NumberedEquation",
  CellTags->"Mellin-Transformation"],

Cell[TextData[{
  "Symmetrical momenta are calculated with the absolute values ",
  Cell[BoxData[
      \(TraditionalForm\`\( \[VerticalBar] x\( \[VerticalBar] \^m\)\)\)]],
  " instead of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^m\)]],
  ", where the integration bounds presuppose a symmetrical distribution \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f[x] = f[ \[VerticalBar] x \[VerticalBar] ]\)]],
  ". The following relation between symmetrical momenta ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( <  \[VerticalBar] x\( \[VerticalBar] \^m\) > \)\)]],
  " and Mellin transformation of a function results:"
}], "Text"],

Cell[BoxData[
    \(\( <  \[VerticalBar] x\( \[VerticalBar] \^m\) > \)\  = \ 
      \( <  \[VerticalBar] x\( \[VerticalBar] \^m\)\), 
    \(f[ \[VerticalBar] x \[VerticalBar] ] > \)\  = \n\t\n
      \(\( = 2  \[ScriptCapitalM]\_x\%\(m + 1\)[f[x]]\) = 
        2 \(\[Integral]\_0\%\[Infinity]\( x\^\(m + 1 - 1\)\) f[x] 
              \(\[DifferentialD]x.\)\)\)\)], "NumberedEquation",
  CellTags->"Symmetrische Momente"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Calculation of the Delta Momenta"
}], "Subsubsection"],

Cell[TextData[{
  "The symmetrical momenta of the delta function yield with the equations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Symmetrische Momente"],
  "), (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "3.Delta-Axiom"],
  "):"
}], "Text"],

Cell[BoxData[
    RowBox[{\( <  \[VerticalBar] x\( \[VerticalBar] \^m\)\), ",", 
      RowBox[{\(\[Delta][x] > \), " ", "=", 
        RowBox[{"{", GridBox[{
              {\(1\ \ \ \ \ \ \ \ \ \ \ m = 0, \)},
              {\(0\ \ \ \ \ \ \ \ \ \ \ m > 0.\)}
              }]}]}]}]], "NumberedEquation",
  CellTags->"Delta-Momente"],

Cell[TextData[{
  "More generally formulated the Mellin transformation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Transformation"],
  ") of the delta function according to relation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") yields a quite peculiar function:"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalM]\_x\%z[\[Delta][x]] = \(\((0\^\(z - 1\)\/2)\).\)\)], 
  "NumberedEquation",
  CellTags->"Null hoch z"],

Cell[TextData[{
  "Function (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Null hoch z"],
  ") is quite peculiar, because the inverse Mellin transformation of ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  " again leads back to the singulary delta function."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Possibilities of Enlarging Function Theory"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "In the face of results like (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Null hoch z"],
  ") also an experienced mathematician reaches his limits. The formal going \
on of calculation with the formally gotten formulae always yields sensible \
results, where even a computer does not find inconsistencies of this \
possibility."
}], "Text"],

Cell[TextData[{
  "The results (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Momente"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Null hoch z"],
  ") with (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Symmetrische Momente"],
  ") suggest the conclusion to define the function values of ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] 0\)]],
  " non-continually to be number one. A direct access via limit calculation \
of the kind ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] 0\)]],
  " then naturally is not possible, but moreover a motivation via an analogy \
to the Hausdorff dimension (",
  ButtonBox["[Non1996]",
    ButtonData:>{"Literatur.nb", "[Non1996]"},
    ButtonStyle->"Hyperlink"],
  ", eq. (2.4), p. 37) of parametric limits:"
}], "Text"],

Cell[BoxData[
    \(0\^z := \(\ lim\)\+\(\[Delta]\  \[Rule] \ 0\)\ \(\[Delta]\^z.\)\)], 
  "NumberedEquation",
  CellTags->"genaueres Null hoch z"],

Cell[TextData[{
  "The peculiarity of the ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  " function is, that the absolute value of the function is unequivocal for \
all ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", while the complex phase especially for pure imaginary ",
  Cell[BoxData[
      \(TraditionalForm\`z \[NotEqual] 0\)]],
  " keeps ready a lot of surprises."
}], "Text"],

Cell[TextData[{
  "Therefore when estimating integral convergence, result expressions of the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`x\^z\)]],
  " give a clear answer for ",
  Cell[BoxData[
      \(TraditionalForm\`Re[x] > 0\)]],
  " and eventually still for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] > 0\)]],
  ". Already the case ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] 0\)]],
  " causes discussions, which within each of the corresponding context of the \
result can be finished, yet."
}], "Text"],

Cell[TextData[{
  "The use of definition (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "genaueres Null hoch z"],
  ") to be an analytical function of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " seems to be as non-usual as the discussion of ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)]],
  " five hundred years ago. To work off unsettled questions of this kind may \
be the aim of later elaborations. The analytical relevance of the ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  " function is yet pointed out by the momenta of the delta function (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Momente"],
  ")."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Laplace  and Fourier Transformation"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Known Relations"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Plan of Action"
}], "Subsubsection"],

Cell[TextData[{
  "With Laplace transformation (",
  ButtonBox["[BrS1987]",
    ButtonData:>{"Literatur.nb", "[BrS1987]"},
    ButtonStyle->"Hyperlink"],
  ", section 4.4.3.1, p. 634) of fractional diffusion equations the \
differentiation sentence and the convolution sentence are sufficient to \
change the integrated form of the time fractional differential equation \
(1.26) into an ordinary differential equation of the spacial coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The integration constants, that are mentioned in Oldham/Spanier (",
  ButtonBox["[OS1974]",
    ButtonData:>{"Literatur.nb", "[OS1974]"},
    ButtonStyle->"Hyperlink"],
  ", section 8.1, p. 133-136) in connection to fractional derivatives, own no \
physical relevance, which results by the discussion of fractional initial \
value problems (references see chapter 1.3.2 of this elaboration). At the \
software package ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " they optionally can be switched on via the option ",
  StyleBox["OldhamSpanierConstants\[Rule]True",
    FontSlant->"Italic"],
  " during carrying-out of Laplace transformation."
}], "Text"],

Cell[TextData[{
  "The subsequent Fourier transformation of these ordinary differential \
equation succeeds, if all initial value problems for the first are set to \
Dirac's delta function. In the easiest case (also with fractional diffusion \
equations!) an algebraic equation is gotten, whose inverse Fourier and \
inverse Laplace transformation lead to an unequivocal fundamental system of \
propagators, which in the context of this elaboration is called the ",
  StyleBox["optimized fundamental system",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
The total solution results by carrying-out each of a Fourier \
convolution of the initial value problems and the corresponding fundamental \
propagators.\
\>", "Text"],

Cell[TextData[{
  "Other solution techniques of linear differential equations e.g. lead to ",
  StyleBox["Frobenius' normal form",
    FontSlant->"Italic"],
  " (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", eq. (11c), p. 188) of a fundamental system."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Idea of Propagator"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The propagator is part of the optimized fundamental system of a partial \
linear differential equation. The corresponding initial value problem always \
is Dirac's delta function at time ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "With the solution strategy being discussed here the time coordinate is to \
be handled differently from the spacial coordinates, because the initial \
value problem describes the spatial distribution ",
  Cell[BoxData[
      \(TraditionalForm\`f[x, t \[Rule] 0]\)]],
  " and not\[LongDash]also being mathematically possible\[LongDash]the time \
development of dynamics at a very certain location ",
  Cell[BoxData[
      \(TraditionalForm\`f[x \[Rule] 0, t]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The Fourier transformation of a differential equation can be understood \
via partial integration, if the so-called ",
  StyleBox["natural boundary conditions",
    FontSlant->"Italic"],
  ", namely the disappearance of the function and its derivatives at \
infinity, are fulfilled. With propagators this demand because of the start at \
",
  Cell[BoxData[
      \(TraditionalForm\`t \[Equal] 0\)]],
  " by a delta function is to be discussed as fulfilled."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Idea of Green's Function"
}], "Subsubsection"],

Cell[TextData[{
  "In opposite to a propagator a Green's function describes the standardized \
solution of an inhomogenous differential equation. Due to Hort/Thoma (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]107-108, p. 178-182) hereby always one additional integration \
is to be done in comparison to homogeneous equations."
}], "Text"],

Cell[TextData[{
  "To get the basic function, which is used for an integration with the \
general inhomogenity or steering size ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t]\)]],
  ", again Dirac's delta function, this time being time dependent, is used."
}], "Text"],

Cell["\<\
The gotten Green's function in the easiest case is subjected to a \
time Laplace convolution and a spatial Fourier convolution to get the general \
inhomogeneous solution of the original equation.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Prolongations"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Laplace Transformation of the Delta Function"
}], "Subsubsection"],

Cell[TextData[{
  "Due to equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") Dirac's delta function has got an unequivocal Laplace transform:"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalL]\_t\%p[\[Delta][t]] = 
      \(\[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(\(-p\)\ t\)\) 
            \[Delta][t] \[DifferentialD]t = \(\((1\/2)\).\)\)\)], 
  "NumberedEquation",
  CellTags->"Laplace-Transformation der Delta-Funktion"],

Cell[TextData[{
  "A lot of publications deviate from this result. Exemplary the references \
may be given only, that occur at ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 in a program comment to the package ",
  StyleBox["Calculus`DiracDelta`",
    FontSlant->"Italic"],
  ": Hoskins ",
  ButtonBox["[Hos1979]",
    ButtonData:>{"Literatur.nb", "[Hos1979]"},
    ButtonStyle->"Hyperlink"],
  " or Antosik, Mikusinski and Sikorski ",
  ButtonBox["[AMS1973]",
    ButtonData:>{"Literatur.nb", "[AMS1973]"},
    ButtonStyle->"Hyperlink"],
  " yield the result number one."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Consequences for Computer Algebra"
}], "Subsubsection"],

Cell["\<\
A mathematician calculating with pencil and paper is able to hold \
out a situative context of the delta function consistently to the end. In \
opposite a computer algebra system must lead to calculation errors with this \
kind of specialities. By this reason the demands for mathematics to be \
formulated consistently are principally heavier by use of computer algebra \
than by the traditional calculation with pencil and paper.\
\>", "Text"],

Cell[TextData[{
  "Because of the situative context with the Laplace transformation of the \
delta function actually no mature computer algebra system exists, where the \
delta function would be implemented consistently or uncontradicted. With ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " yet it has been possible to reach a consistent implementation of the \
delta function in the context of this elaboration. Now the result is not \
called ",
  StyleBox["DiracDelta",
    FontSlant->"Italic"],
  ", what would describe the historical facts better, but ",
  StyleBox["SymmetricalDelta",
    FontSlant->"Italic"],
  ", because this function name had not been used, yet."
}], "Text"],

Cell[TextData[{
  "In this context mainly an \"open\" computer algebra system turns out to be \
useful, because the user of the program in the case of need must practise \
himself the necessary corrections of the system. The software package ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is \"half open\", what means, that eventual changes of functions are to \
be implemented by an own name."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Laplace Convolution with Delta Function"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The Laplace convolution with a delta function according to equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") yields half of the convoluted function:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%t \[Delta][\[Tau]] f[t - \[Tau]] 
          \[DifferentialD]\[Tau] = 
      \(\[Integral]\_0\%t \[Delta][t - \[Tau]] f[\[Tau]] 
            \[DifferentialD]\[Tau] = \(\((f[t]\/2)\).\)\)\)], 
  "NumberedEquation",
  CellTags->"Laplace-Faltung mit Delta-Funktion"],

Cell[TextData[{
  "Certainly it is not very practical to keep always ones mind to this factor \
",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " when comparing with literature. Moreover it is suitable to exchange the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Delta][t]\)]],
  " instead of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][t]\)]],
  " with the inhomogenity of the equation when applying Laplace \
transformation. The Laplace transform of this then is number one, and Green's \
function results to be that function, whose Laplace convolution with the \
steering size yields the general solution."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Space and Time Dependent Steering Functions"
}], "Subsubsection"],

Cell[TextData[{
  "With space and time dependent steering functions ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, y, z, t]\)]],
  " the independency of the coordinates is used thus leading to the following \
more general inhomogenity to get Green's function:"
}], "Text"],

Cell[BoxData[
    \(s[x, y, z, t] \[Rule] 
      2  \[Delta][x] \[Delta][y] \[Delta][z] \(\[Delta][t].\)\)], 
  "NumberedEquation",
  CellTags->"\[CapitalUDoubleDot]bergang zur Greenschen Funktion"],

Cell[TextData[{
  "On equations with spatial independent analytical coefficients, e.g. the \
fractional diffusion equation (1.26), Green's function is contained within \
the fundamental system of the propagators. This results from the Laplace \
transformation of a corresponding example equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] \[Element] \(\[DoubleStruckCapitalN] : \)\)]]
  
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalL]\_t\%p[
              \[PartialD]\^\[Beta] f[x, t]\/\[PartialD]t\^\[Beta] - 
                  \[PartialD]\^2 f[x, t]\/\[PartialD]x\^2 = 
                2  \[Delta][x] \[Delta][t]]\n\n
            \[DoubleLongLeftRightArrow]\ \ \ \ p\^\[Beta] 
           \[ScriptCapitalL]\_t\%p[f[x, t]] - 
        \[Sum]\+\(n = 0\)\%\(\[Beta] - 1\)\[Delta][x] 
            p\^\(\[Beta] - 1 - n\) - 
        \[PartialD]\^2 \[ScriptCapitalL]\_t\%p[f[x, t]]\/\[PartialD]x\^2 = 
      \(\[Delta][x].\)\)], "NumberedEquation",
  CellTags->"Beispiel zur Greenschen Funktion"],

Cell[TextData[{
  "The total identity of one of the propagators to Green's function thus is \
shown for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Equal] \[Beta] - 1\)]],
  ". More difficult inhomogeneous equations eventually can be handled via the \
homogeneous solution (there are more solution techniques for this!)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Space Dependent Analytical Coefficients"
}], "Subsubsection",
  PageBreakAbove->True],

Cell["\<\
If the analytical coefficients of an equation are space dependent, \
a special handling is necessary to calculate the general solution. For this \
the integral of a Fourier convolution is viewed for the first:\
\>", "Text"],

Cell[BoxData[
    \(f[x]*g[x] = 
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[x - a] g[a] 
            \[DifferentialD]a = 
        \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[a] g[x - a] 
            \(\[DifferentialD]a.\)\)\)], "NumberedEquation",
  CellTags->"Fourier-Faltung"],

Cell[TextData[{
  "If now the propagator is build up, then at starting time ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] 0\)]],
  " a normal delta convolution according to equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Theorem"],
  ") is available. However at later time now no more a Fourier convolution is \
to be calculated, but an integral, which summarizes the spacial dependent \
propagators having the starting distribution as weight."
}], "Text"],

Cell[TextData[{
  "Certainly spacial dependent propagators are yielded only, if also \
accordingly ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta][x - a] + \[Delta][x + a]\)\/2\)]],
  " is set instead of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x]\)]],
  " to be a symmetrical initial value problem. The same handling also is to \
be noted at the building of Green's function. In the Fourier convolution (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Faltung"],
  ") both the propagators and also Green's function depend on the integration \
distance ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " only. With asymmetric equations also an asymmetric initial value problem \
of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x - a]\)]],
  " is to be started with to find the propagators."
}], "Text"],

Cell["\<\
These connection are of value to solve corresponding Fokker Planck \
equations (chapter 1.2.2.3 and 2.4.1.1 of this elaboration). Here they shall \
not be discussed further on, because they would exceed the setting of this \
elaboration.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Fourier Transformation of the Riesz Operator"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The Riesz operator is presented in Samko et al. (",
  ButtonBox["[SKM1993]",
    ButtonData:>{"Literatur.nb", "[SKM1993]"},
    ButtonStyle->"Hyperlink"],
  ", eqs. (12.1)\[Dash](12.4), p. 214) in such a way, that all symmetric and \
asymmetric variants of the Riesz operators can be build up therewith."
}], "Text"],

Cell[TextData[{
  "When discussing diffusion without shifting of the focal point the \
following definition is sufficient, which also can be understood as Fourier \
convolution with the power of the absolute value function, and thus leads to \
the Mellin transformation of the cosine function (",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", formulae I.1.2 and I.5.2, p. 11 and 42; ",
  ButtonBox["[EMOT1953]",
    ButtonData:>{"Literatur.nb", "[EMOT1953]"},
    ButtonStyle->"Hyperlink"],
  ", eqs. 1.2(7) and 1.2(15), p. 3 and 5):"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\_x\%k[\(-\(|x\)\)\(|\^\(\(-\[Mu]\) - 1\)\)] = 
      \(\(-\(\[Integral]\_\(-
                \[Infinity]\)\%\[Infinity]\( 
                  \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\) 
              \(\((\(|x | \))\)\^\(\(-\[Mu]\) - 1\)\) \[DifferentialD]x\)\) = 
        \n\t\t\n\(\( = \(-2\) 
            \[Integral]\_0\%\[Infinity] Cos[\(|k | \ x\)]\ 
                \(x\^\(\(-\[Mu]\) - 1\)\) \[DifferentialD]x\) = 
          \(\(-\[ScriptCapitalM]\_x\%\(-\[Mu]\)[Cos[\(|k | \ x\)]]\) = \n
            \t\t\t\t\t\n
            \(\( = \(-\((\(|k | \))\)\^\[Mu]\) \[CapitalGamma][\(-\[Mu]\)] 
                Cos[\(-\(\(\[Mu]\ \[Pi]\)\/2\)\)]\) = 
              \(-\(\(\(2\^\(-\[Mu]\)\) \(\@\[Pi]\) 
                        \[CapitalGamma][\(-\(\[Mu]\/2\)\)]\)\/\[CapitalGamma][
                        \(\[Mu] + 1\)\/2]\)\) 
                \(\((\(|k | \))\)\^\[Mu].\)\)\)\)\)\)], "NumberedEquation",
  CellTags->"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"],

Cell[TextData[{
  "The Riesz operator to be found here is to be build up in such a way, that \
for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[Rule] 2\)]],
  " results the Fourier transform of the second derivative, namely ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\^2\)\)]],
  " as a multiplicator."
}], "Text"],

Cell[TextData[{
  "This aim is reached by the following Fourier convolution, where connects \
to the Riesz operator an integral order ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Mu]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " here shall present the fractional differentiation order:"
}], "Text"],

Cell[BoxData[
    \(\(-\[ScriptCapitalR]\_x\%\(-\[Mu]\)[f[x]]\) = 
      \(\(-\(\(\(2\^\[Mu]\) 
                  \[CapitalGamma][\(\[Mu] + 1\)\/2]\)\/\(\(\@\[Pi]\) 
                  \[CapitalGamma][\(-\(\[Mu]\/2\)\)]\)\)\) 
          \(\[Integral]\_\(-
                \[Infinity]\)\%\[Infinity]\( f[y]
                    \/\(\( \[VerticalBar] x - y
                      \)\( \[VerticalBar] \^\(\[Mu] + 1\)\)\)\) 
              \[DifferentialD]y\) = \n\t\t\n
        \( = \(\((\[ScriptCapitalF]\^\(-1\))\)\_k\%x[
              \(-\(|k \((|\^\[Mu]\ \[ScriptCapitalF])\)\_x\%k[f[\(|k | \)]]
                    \)\)].\)\)\)\)], "NumberedEquation",
  CellTags->"diffusions-relevanter Riesz-Operator"],

Cell[TextData[{
  "The formulation of this operator leads back to the elaboration of V. \
Seshadri and B. J. West ",
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  ". The Fourier transformation of the Riesz operator being possible for \
driftless diffusion is given by equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "diffusions-relevanter Riesz-Operator"],
  ")."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Mellin Transformation"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Difference Equations"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Generating Linear Difference Equations"
}], "Subsubsection"],

Cell[TextData[{
  "Laplace transformation of a time fractional diffusion equation also leads \
for space dependent diffusion parameters\[LongDash]e.g. dependent of power \
terms due to the notation of Risken (",
  ButtonBox["[Ris1984]",
    ButtonData:>{"Literatur.nb", "[Ris1984]"},
    ButtonStyle->"Hyperlink"],
  ", chap. 1.2.1, p. 4-5)\[LongDash]to an ordinary differential equation of \
the spatial coordinate, whose inhomogeneous solution is asked \
for\[LongDash]in the case of the given example to the basic equations of the \
Bessel functions."
}], "Text"],

Cell[TextData[{
  "Mellin transformation of an ordinary homogeneous differential equation \
leads to the corresponding difference equation (",
  ButtonBox["[Mes1959]",
    ButtonData:>{"Literatur.nb", "[Mes1959]"},
    ButtonStyle->"Hyperlink"],
  ", chap. X.1, p. 133-134). If relation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Beispiel zur Greenschen Funktion"],
  ") is established at least for special initial value problems (e.g. for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x - 0]\)]],
  "), then the solution of the homogeneous difference equation of Mellin \
space is enough to solve the originally inhomogeneous differential equation."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Solution of Linear Difference Equations"
}], "Subsubsection"],

Cell[TextData[{
  "There are solution techniques (see ",
  ButtonBox["[Mes1959]",
    ButtonData:>{"Literatur.nb", "[Mes1959]"},
    ButtonStyle->"Hyperlink"],
  ") of homogeneous and inhomogeneous linear difference equations. Sometimes \
it is possible to guess one of the homogeneous solutions of a difference \
equation, especially if the solving function of the original equation is a \
Fox's H-function. Namely then the Mellin transform of the solution only \
consists of fractions of Euler's gamma function having no sum terms. Detailed \
information about this can be found in the diploma thesis of the author (",
  ButtonBox["[S\[UDoubleDot]d1997]",
    ButtonData:>{"Literatur.nb", "[Sued1997]"},
    ButtonStyle->"Hyperlink"],
  ", sections 5.1.1 and 6.1, p. 65-66 and 75-79)."
}], "Text"],

Cell[TextData[{
  "In Mellin space it is easy to convert by combinatorics and clever \
cancelling a yielded main solution by use of the reflection formula (",
  ButtonBox["[EMOT1953]",
    ButtonData:>{"Literatur.nb", "[EMOT1953]"},
    ButtonStyle->"Hyperlink"],
  ", eqs. 1.2(6) and 1.2(7), p. 3) into further main solutions (cmp. ",
  ButtonBox["[Mes1959]",
    ButtonData:>{"Literatur.nb", "[Mes1959]"},
    ButtonStyle->"Hyperlink"],
  ", rem. at p. 41) due to the sampling theorem (",
  ButtonBox["[Mar1986]",
    ButtonData:>{"Literatur.nb", "[Mar1986]"},
    ButtonStyle->"Hyperlink"],
  ", chap. 6, p. 127-131). This possibility is dealed with by Mellin by the \
name \"proper substitution\" (",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", end of \[Section]5, p. 314)."
}], "Text"],

Cell[TextData[{
  "Within the setting of this elaboration fortunately it has not been \
possible to try out the efficiency of the difference equations. In the \
diploma thesis of S. Hoffmann ",
  ButtonBox["[Hoff2000]",
    ButtonData:>{"Literatur.nb", "[Hoff2000]"},
    ButtonStyle->"Hyperlink"],
  " there are several realizations of solution techniques and a lot of \
interesting references to this topic."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Fox's H-function"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The inverse Mellin transformation of fractions of Euler's gamma functions \
having no sum terms according to Dixon/Ferrar ",
  ButtonBox["[DF1936]",
    ButtonData:>{"Literatur.nb", "[DF1936]"},
    ButtonStyle->"Hyperlink"],
  " yields a class of functions, which today ",
  ButtonBox["[MS1978]",
    ButtonData:>{"Literatur.nb", "[MS1978]"},
    ButtonStyle->"Hyperlink"],
  " is called Fox's H-function, because C. Fox ",
  ButtonBox["[Fox1961]",
    ButtonData:>{"Literatur.nb", "[Fox1961]"},
    ButtonStyle->"Hyperlink"],
  " did not know about the elaboration of his predecessors."
}], "Text"],

Cell[TextData[{
  "Happen fractions of Euler's gamma functions having sum terms to be a \
solution, then Baumann's \[Aleph]-functions ",
  ButtonBox["[SBN1998]",
    ButtonData:>{"Literatur.nb", "[SBN1998]"},
    ButtonStyle->"Hyperlink"],
  " result, a generalization of Saxena's I-function ",
  ButtonBox["[Sax1982]",
    ButtonData:>{"Literatur.nb", "[Sax1982]"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "The presentation of Fox's H-function to be an inverse Mellin transform \
results (",
  ButtonBox["[SBN1998]",
    ButtonData:>{"Literatur.nb", "[SBN1998]"},
    ButtonStyle->"Hyperlink"],
  ", eq. (1), p. 401) for positive ",
  Cell[BoxData[
      \(TraditionalForm\`A\_j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_j\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm
      \`{m, n, p, q} \[Element] \[DoubleStruckCapitalN]\_0\)]],
  " in:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SubsuperscriptBox[
          StyleBox["\[ScriptCapitalH]",
            FontSize->16], \(p, q\), \(m, n\)], "[", 
        RowBox[{"x", "|", GridBox[{
             
               {\({{a\_1, A\_1}, ..., {a\_n, A\_n}} | \), 
                \({{a\_\(n + 1\), A\_\(n + 1\)}, ..., {a\_p, A\_p}}\)},
             
               {\({{b\_1, B\_1}, ..., {b\_m, B\_m}} | \), 
                \({{b\_\(m + 1\), B\_\(m + 1\)}, ..., {b\_q, B\_q}}\)}
              }]}], "]"}], "=", "\n", "\t", "\n", 
      \( = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \[Integral]\_\(\(-\[ImaginaryI]\)\ \[Infinity]\)\%\(\[ImaginaryI]\ 
              \[Infinity]\)\(\(\((
                    \[Product]\+\(j = 1\)\%m \[CapitalGamma][
                        b\_j + \(B\_j\) z])\) 
                  \((\[Product]\+\(j = 1\)\%n \[CapitalGamma][
                        1 - a\_j - \(A\_j\) z])\)\)\/\(\((
                    \[Product]\+\(j = m + 1\)\%q \[CapitalGamma][
                        1 - b\_j - \(B\_j\) z])\) 
                  \((\[Product]\+\(j = n + 1\)\%p \[CapitalGamma][
                        a\_j + \(A\_j\) z])\)\)\) \(x\^\(-z\)\) 
            \(\[DifferentialD]z.\)\)}]], "NumberedEquation",
  CellTags->"Foxsche H-Funktion"],

Cell[TextData[{
  "Even more complicated Mellin Barnes integrals result, if Riemann's or even \
Hurwitz's zeta function or better the yet more general Lerch's zeta or phi \
function occurs in Mellin space to be a solution (examples for this: ",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", formula I.3.24\[Dash]I.3.26 and A.16, p. 28 and 272). The numerical \
series of this kind of functions usually is won via the residual sentence by \
use of the preparatory elaborations of Mellin ",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  " and Barnes ",
  ButtonBox["[Bar1908]",
    ButtonData:>{"Literatur.nb", "[Bar1908]"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "The essential difference between a power series and an analytical function \
due to Barnes ",
  ButtonBox["[Bar1908]",
    ButtonData:>{"Literatur.nb", "[Bar1908]"},
    ButtonStyle->"Hyperlink"],
  " consists in the fact, that a function has got an analytical continuation \
possibly to the whole complex number area and corresponding analytical \
properties, while the power series is interesting for numerics."
}], "Text"],

Cell["\<\
In the case of Bessel's differential equation being mentioned as an \
example, the Mellin transformation yields an easy difference equation, where \
the inverse Mellin transformation of altogether four main solutions yields \
not only an optimized fundamental system of two modified Bessel functions of \
first kind, but also the modified Bessel function of second kind being very \
important for the propagators. The fourth main solution cannot be subjected \
to the inverse Mellin transformation.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Momenta Calculation from Laplace Transforms"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell["\<\
Since in this elaboration rather the discussion of the theoretical \
variance in comparison to measured data is dealed with, it is important to \
calculate the momenta of a solution function reliably also for the case, that \
the solution function itself already is too complicated, namely exceeds the \
setting of Fox's H-functions.\
\>", "Text"],

Cell[TextData[{
  "Since momenta according to equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Symmetrische Momente"],
  ") are related to Mellin transformation, their calculation principally is \
easier than the calculation of a completed solution function. The deeper \
reason for this is the convolution sentence of Mellin transformation (",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", formulae I.1.13\[Dash]I.1.15, p. 12), which e.g. converts the Mellin \
transform of a Fourier convolution into a Fox's H-function, yet."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Calculation"
}], "Subsubsection"],

Cell["\<\
Since the Laplce transform of the solution function already has got \
the spatial coordinates, the momenta of the Laplace transform also can be \
calculated directly. From the corresponding result the inverse Laplace \
transform into the time coordinate is to be build.\
\>", "Text"],

Cell[TextData[{
  "According to Oberhettinger (",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", eq. (c'), p. 3) a Mellin transform of a Laplace transformation results \
to be"
}], "Text"],

Cell[BoxData[
    \(\(\[ScriptCapitalM]\_p\%y[\[ScriptCapitalL]\_t\%p[f[x, t]]] = 
      \[CapitalGamma][y] \[ScriptCapitalM]\_t\%\(1 - y\)[f[x, t]], \)\)], 
  "NumberedEquation",
  CellTags->"Mellin-Laplace-Transformation"],

Cell["\<\
which also enables the calculation of the inverse Laplace \
transformation via Mellin transformation.\
\>", "Text"],

Cell[TextData[{
  "If e.g. the momenta calculation of a Laplace transform yields a Fox's \
H-function, then because of the result (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Laplace-Transformation"],
  ") also the moment of the distribution results to be a Fox's H-function. \
The distribution function itself is much more complicated in this case."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Momenta Calculation from Fourier Transforms"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Direct Calculation"
}], "Subsubsection"],

Cell["\<\
If the Fourier transform of a distribution function is known only, \
then the momenta calculation turns out to be much more tricky than with the \
Laplace transform, because now the spatial coordinate itself is not known at \
all.\
\>", "Text"],

Cell[TextData[{
  "In spite of this for symmetrical Fourier transforms (which are to be \
discussed preferably with driftless diffusion) generally it is possible to \
derive the following relation, indeed via Mellin transformation of an inverse \
Fourier transform by use of the Fubini theorem (",
  ButtonBox["[SKM1993]",
    ButtonData:>{"Literatur.nb", "[SKM1993]"},
    ButtonStyle->"Hyperlink"],
  ", eq. (1.32), p. 9), which arranges the swapping of integrals, where again \
as in relation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", 
  "Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"],
  ") the Mellin transform of the cosine function occurs:"
}], "Text"],

Cell[BoxData[
    RowBox[{\( < \((\(|x\(|\^m\)\))\)\), ",", 
      RowBox[{
      \(\((\[ScriptCapitalF]\^\(-1\))\)\_k\%x[f[\(|k | \), t]] > \), " ", "=",
         
        RowBox[{
        \(\[Integral]\_\(-
                \[Infinity]\)\%\[Infinity]\(\(|x\(|\^m\)\)\/\(2  \[Pi]\)\) 
              \((\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[\(|k | \), t] 
                    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\) 
                    \[DifferentialD]k)\) \[DifferentialD]x\), "=", "\n", 
          "\t\t", "\n", 
          RowBox[{"=", 
            RowBox[{
            \(\(4\/\(2  \[Pi]\)\) 
                \(\[Integral]\_0
                    \%\[Infinity]\((
                      \[Integral]\_0\%\[Infinity] Cos[\(|k | \ x\)] \(x\^m\) 
                          \[DifferentialD]x)\) f[k, t] \[DifferentialD]k\)\), 
              "=", "\n", "\t\t\t\t", "\n", 
              RowBox[{"=", 
                RowBox[{
                  FractionBox[
                    RowBox[{\(2\^\(1 + m\)\), " ", 
                      RowBox[{
                        StyleBox["\[CapitalGamma]",
                          FontSlant->"Italic"], "[", \(1\/2 + m\/2\), "]"}], 
                      " ", \(\[ScriptCapitalM]\_k\%\(-m\)[f[k, t]]\)}], 
                    RowBox[{\(\@\[Pi]\), " ", 
                      RowBox[{
                        StyleBox["\[CapitalGamma]",
                          FontSlant->"Italic"], "[", \(-\(m\/2\)\), "]"}]}]], 
                  "."}]}]}]}]}]}]}]], "NumberedEquation",
  CellTags->"Momente aus Fourier-Transformierter"],

Cell[TextData[{
  "The Mellin transform of the Fourier transform must be very suitable, that \
the result (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Momente aus Fourier-Transformierter"],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] 2\)]],
  " allows the calculation of variance."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Momenta of a Fourier Convolution"
}], "Subsubsection"],

Cell["\<\
The momenta of a Fourier convolution result to a fundamentally \
easier theorem (appendix A of this elaboration), which here at least shall be \
mentioned:\
\>", "Text"],

Cell[BoxData[
    RowBox[{\( < \((x\^m)\)\), ",", 
      RowBox[{\(f[x]*g[x] > \), " ", "=", 
        RowBox[{
          RowBox[{\(\[Sum]\+\(k = 0\)\%m\), 
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {"m"},
                  {"k"}
                  }], "\[NegativeThinSpace]", ")"}]}], " ", "<", \(x\^k\)}]}],
       ",", \(f[x] > \  < x\^\(m - k\)\), ",", \(g[x] > .\)}]], 
  "NumberedEquation",
  CellTags->"Momententheorem"],

Cell[TextData[{
  "The difference between the equations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Momente aus Fourier-Transformierter"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Momententheorem"],
  ") mainly consists in the fact, that on the one hand the symmetrical \
momenta and on the other hand the factual momenta are calculated."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Summary"
}], "Section",
  PageBreakAbove->True],

Cell["\<\
Dirac's delta function being important to the variance theorem \
(1.14) very much has been introduced as an analytical function of the complex \
number area being consistent due to function theory.\
\>", "Text"],

Cell["\<\
The use of the delta function when applying Laplace and Fourier \
transformations to a fractional linear equation has been dealed with. The \
results are optimized fundamental systems of propagators, which eventually \
already contain the Green's function of the inhomogenity.\
\>", "Text"],

Cell[TextData[{
  "The Riesz operator due to B. J. West ",
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  " being useful for the discussion of driftless diffusion has been \
introduced as an elegantly arranged Fourier convolution."
}], "Text"],

Cell["\<\
The direct Mellin transformation of a linear differential equation \
often leads to a difference equation, whose solution manifold can widely \
exceed beyond the Mellin transforms of Fox's H-functions.\
\>", "Text"],

Cell["\<\
The calculation of momenta from Laplace or Fourier transforms of a \
distribution function has been introduced. This deal simplifies the \
analytical discussion enormously, since the variance of a solution propagator \
principally belongs to an easier function class than the solution propagator \
itself.\
\>", "Text"],

Cell["", "Text",
  PageBreakAbove->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Working",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{736, 489},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->31,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Kapitel 2. Mathematische Methoden"}], "Header"]}, {Cell[ 
        TextData[ {"Kapitel 2. Mathematische Methoden"}], "Header"], 
      Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle",
    TextAlignment->Left],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Remark", "Subsubsection"],
  
  Cell[TextData[{
    "The following commands are removed from some of the following \
definitions. To know them anyway they are listed:\n\t",
    StyleBox[" FontSlant->\"Italic\"", "Input"],
    ", \n\t  ",
    StyleBox["SingleLetterItalics->True", "Input"]
  }], "Text"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->PaperWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->PaperWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    TextJustification->1,
    FontFamily->"Arial"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {4, 4}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->True,
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->GrayLevel[0.666667]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section",
    CellFrame->{{0, 0}, {0, 2}}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Fourier-Transformation"->{
    Cell[4996, 170, 235, 4, 55, "NumberedEquation",
      CellTags->"Fourier-Transformation"]},
  "Cosinus-Transformation"->{
    Cell[5441, 183, 193, 4, 55, "NumberedEquation",
      CellTags->"Cosinus-Transformation"]},
  "Fourier-Transformation der Eins"->{
    Cell[6376, 220, 501, 10, 59, "NumberedEquation",
      CellTags->"Fourier-Transformation der Eins"]},
  "1.Delta-Axiom"->{
    Cell[8416, 283, 144, 3, 35, "NumberedEquation",
      CellTags->"1.Delta-Axiom"]},
  "2.Delta-Axiom"->{
    Cell[8563, 288, 166, 3, 55, "NumberedEquation",
      CellTags->"2.Delta-Axiom"]},
  "3.Delta-Axiom"->{
    Cell[8732, 293, 111, 2, 35, "NumberedEquation",
      CellTags->"3.Delta-Axiom"]},
  "Praktisches Delta-Integral"->{
    Cell[9681, 324, 232, 4, 57, "NumberedEquation",
      CellTags->"Praktisches Delta-Integral"]},
  "Delta-Theorem"->{
    Cell[10234, 339, 177, 3, 55, "NumberedEquation",
      CellTags->"Delta-Theorem"]},
  "Fourier-Transformation der Delta-Funktion"->{
    Cell[11237, 373, 304, 5, 55, "NumberedEquation",
      CellTags->"Fourier-Transformation der Delta-Funktion"]},
  "Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"->{
    Cell[11957, 392, 397, 6, 56, "NumberedEquation",
      CellTags->"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"]},
  "Fourier-Mellin-Transformationen"->{
    Cell[13672, 452, 1365, 26, 212, "NumberedEquation",
      CellTags->"Fourier-Mellin-Transformationen"]},
  "Mellin-Transformation der Eins"->{
    Cell[15623, 498, 285, 5, 55, "NumberedEquation",
      CellTags->"Mellin-Transformation der Eins"]},
  "Mellin-Residuum der Delta-Funktion"->{
    Cell[16626, 536, 317, 5, 57, "NumberedEquation",
      CellTags->"Mellin-Residuum der Delta-Funktion"]},
  "Mellin-Transformation der Eins explizit 1.Teil"->{
    Cell[18574, 600, 372, 6, 110, "NumberedEquation",
      CellTags->"Mellin-Transformation der Eins explizit 1.Teil"]},
  "Mellin-Transformation der Eins explizit 2.Teil"->{
    Cell[20284, 647, 254, 4, 56, "NumberedEquation",
      CellTags->"Mellin-Transformation der Eins explizit 2.Teil"]},
  "Momente"->{
    Cell[24170, 782, 250, 5, 55, "NumberedEquation",
      CellTags->"Momente"]},
  "Mellin-Transformation"->{
    Cell[24662, 797, 204, 4, 55, "NumberedEquation",
      CellTags->"Mellin-Transformation"]},
  "Symmetrische Momente"->{
    Cell[25518, 821, 419, 7, 108, "NumberedEquation",
      CellTags->"Symmetrische Momente"]},
  "Delta-Momente"->{
    Cell[26581, 860, 332, 7, 57, "NumberedEquation",
      CellTags->"Delta-Momente"]},
  "Null hoch z"->{
    Cell[27281, 881, 139, 3, 59, "NumberedEquation",
      CellTags->"Null hoch z"]},
  "genaueres Null hoch z"->{
    Cell[29309, 955, 147, 3, 45, "NumberedEquation",
      CellTags->"genaueres Null hoch z"]},
  "Laplace-Transformation der Delta-Funktion"->{
    Cell[37464, 1240, 277, 5, 56, "NumberedEquation",
      CellTags->"Laplace-Transformation der Delta-Funktion"]},
  "Laplace-Faltung mit Delta-Funktion"->{
    Cell[40682, 1339, 298, 6, 56, "NumberedEquation",
      CellTags->"Laplace-Faltung mit Delta-Funktion"]},
  "\[CapitalUDoubleDot]bergang zur Greenschen Funktion"->{
    Cell[42167, 1387, 198, 4, 35, "NumberedEquation",
      CellTags->"\[CapitalUDoubleDot]bergang zur Greenschen Funktion"]},
  "Beispiel zur Greenschen Funktion"->{
    Cell[42783, 1403, 592, 11, 153, "NumberedEquation",
      CellTags->"Beispiel zur Greenschen Funktion"]},
  "Fourier-Faltung"->{
    Cell[44225, 1446, 289, 6, 55, "NumberedEquation",
      CellTags->"Fourier-Faltung"]},
  "Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"->{
    Cell[47380, 1537, 1012, 17, 234, "NumberedEquation",
      CellTags->"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"]},
  "diffusions-relevanter Riesz-Operator"->{
    Cell[49057, 1578, 701, 13, 139, "NumberedEquation",
      CellTags->"diffusions-relevanter Riesz-Operator"]},
  "Foxsche H-Funktion"->{
    Cell[56215, 1802, 1271, 26, 157, "NumberedEquation",
      CellTags->"Foxsche H-Funktion"]},
  "Mellin-Laplace-Transformation"->{
    Cell[61467, 1951, 224, 4, 42, "NumberedEquation",
      CellTags->"Mellin-Laplace-Transformation"]},
  "Momente aus Fourier-Transformierter"->{
    Cell[63632, 2023, 1570, 33, 241, "NumberedEquation",
      CellTags->"Momente aus Fourier-Transformierter"]},
  "Momententheorem"->{
    Cell[65965, 2090, 460, 11, 69, "NumberedEquation",
      CellTags->"Momententheorem"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Fourier-Transformation", 108395, 3610},
  {"Cosinus-Transformation", 108521, 3613},
  {"Fourier-Transformation der Eins", 108656, 3616},
  {"1.Delta-Axiom", 108783, 3619},
  {"2.Delta-Axiom", 108891, 3622},
  {"3.Delta-Axiom", 108999, 3625},
  {"Praktisches Delta-Integral", 109120, 3628},
  {"Delta-Theorem", 109241, 3631},
  {"Fourier-Transformation der Delta-Funktion", 109378, 3634},
  {"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig", 109557, 3637},
  {"Fourier-Mellin-Transformationen", 109726, 3640},
  {"Mellin-Transformation der Eins", 109873, 3643},
  {"Mellin-Residuum der Delta-Funktion", 110020, 3646},
  {"Mellin-Transformation der Eins explizit 1.Teil", 110183, 3649},
  {"Mellin-Transformation der Eins explizit 2.Teil", 110359, 3652},
  {"Momente", 110495, 3655},
  {"Mellin-Transformation", 110606, 3658},
  {"Symmetrische Momente", 110730, 3661},
  {"Delta-Momente", 110847, 3664},
  {"Null hoch z", 110954, 3667},
  {"genaueres Null hoch z", 111069, 3670},
  {"Laplace-Transformation der Delta-Funktion", 111214, 3673},
  {"Laplace-Faltung mit Delta-Funktion", 111373, 3676},
  {"\[CapitalUDoubleDot]bergang zur Greenschen Funktion", 111542, 3679},
  {"Beispiel zur Greenschen Funktion", 111709, 3682},
  {"Fourier-Faltung", 111842, 3685},
  {"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator", 111996, 3688},
  {"diffusions-relevanter Riesz-Operator", 112174, 3691},
  {"Foxsche H-Funktion", 112314, 3694},
  {"Mellin-Laplace-Transformation", 112448, 3697},
  {"Momente aus Fourier-Transformierter", 112596, 3700},
  {"Momententheorem", 112733, 3703}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 29, 0, 79, "Subtitle"],

Cell[CellGroupData[{
Cell[1763, 53, 75, 1, 153, "Title",
  CounterAssignments->{{"Title", 1}}],

Cell[CellGroupData[{
Cell[1863, 58, 102, 5, 75, "Section"],
Cell[1968, 65, 430, 9, 113, "Text"],
Cell[2401, 76, 443, 9, 136, "Text"],
Cell[2847, 87, 441, 8, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3325, 100, 114, 5, 75, "Section"],

Cell[CellGroupData[{
Cell[3464, 109, 148, 7, 67, "Subsection"],
Cell[3615, 118, 187, 4, 67, "Text"],
Cell[3805, 124, 288, 5, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4130, 134, 190, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[4345, 146, 207, 9, 60, "Subsubsection"],
Cell[4555, 157, 438, 11, 113, "Text"],
Cell[4996, 170, 235, 4, 55, "NumberedEquation",
  CellTags->"Fourier-Transformation"],
Cell[5234, 176, 204, 5, 67, "Text"],
Cell[5441, 183, 193, 4, 55, "NumberedEquation",
  CellTags->"Cosinus-Transformation"],
Cell[5637, 189, 121, 3, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5795, 197, 209, 9, 60, "Subsubsection"],
Cell[6007, 208, 366, 10, 67, "Text"],
Cell[6376, 220, 501, 10, 59, "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins"],
Cell[6880, 232, 477, 11, 113, "Text"],
Cell[7360, 245, 291, 7, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7688, 257, 240, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[7931, 269, 482, 12, 90, "Text"],
Cell[8416, 283, 144, 3, 35, "NumberedEquation",
  CellTags->"1.Delta-Axiom"],
Cell[8563, 288, 166, 3, 55, "NumberedEquation",
  CellTags->"2.Delta-Axiom"],
Cell[8732, 293, 111, 2, 35, "NumberedEquation",
  CellTags->"3.Delta-Axiom"],
Cell[8846, 297, 301, 8, 90, "Text"],
Cell[9150, 307, 528, 15, 113, "Text"],
Cell[9681, 324, 232, 4, 57, "NumberedEquation",
  CellTags->"Praktisches Delta-Integral"],
Cell[9916, 330, 315, 7, 90, "Text"],
Cell[10234, 339, 177, 3, 55, "NumberedEquation",
  CellTags->"Delta-Theorem"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10448, 347, 235, 9, 60, "Subsubsection"],
Cell[10686, 358, 548, 13, 113, "Text"],
Cell[11237, 373, 304, 5, 55, "NumberedEquation",
  CellTags->"Fourier-Transformation der Delta-Funktion"],
Cell[11544, 380, 410, 10, 113, "Text",
  PageBreakAbove->True],
Cell[11957, 392, 397, 6, 56, "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"],
Cell[12357, 400, 343, 8, 90, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12749, 414, 165, 7, 67, "Subsection"],

Cell[CellGroupData[{
Cell[12939, 425, 205, 9, 60, "Subsubsection"],
Cell[13147, 436, 522, 14, 113, "Text"],
Cell[13672, 452, 1365, 26, 212, "NumberedEquation",
  CellTags->"Fourier-Mellin-Transformationen"],
Cell[15040, 480, 580, 16, 90, "Text"],
Cell[15623, 498, 285, 5, 55, "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15945, 508, 232, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[16180, 520, 443, 14, 67, "Text"],
Cell[16626, 536, 317, 5, 57, "NumberedEquation",
  CellTags->"Mellin-Residuum der Delta-Funktion"],
Cell[16946, 543, 480, 12, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17463, 560, 195, 9, 60, "Subsubsection"],
Cell[17661, 571, 456, 12, 113, "Text"],
Cell[18120, 585, 451, 13, 90, "Text"],
Cell[18574, 600, 372, 6, 110, "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 1.Teil"],
Cell[18949, 608, 1068, 28, 205, "Text"],
Cell[20020, 638, 261, 7, 90, "Text"],
Cell[20284, 647, 254, 4, 56, "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 2.Teil"],
Cell[20541, 653, 554, 11, 136, "Text",
  PageBreakAbove->True],
Cell[21098, 666, 274, 5, 90, "Text"],
Cell[21375, 673, 435, 10, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21847, 688, 211, 9, 60, "Subsubsection"],
Cell[22061, 699, 260, 7, 67, "Text"],
Cell[22324, 708, 205, 6, 67, "Text"],
Cell[22532, 716, 469, 14, 90, "Text"],
Cell[23004, 732, 307, 7, 90, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23360, 745, 187, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[23572, 757, 223, 9, 60, "Subsubsection"],
Cell[23798, 768, 369, 12, 67, "Text"],
Cell[24170, 782, 250, 5, 55, "NumberedEquation",
  CellTags->"Momente"],
Cell[24423, 789, 236, 6, 67, "Text"],
Cell[24662, 797, 204, 4, 55, "NumberedEquation",
  CellTags->"Mellin-Transformation"],
Cell[24869, 803, 646, 16, 113, "Text"],
Cell[25518, 821, 419, 7, 108, "NumberedEquation",
  CellTags->"Symmetrische Momente"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25974, 833, 203, 9, 60, "Subsubsection"],
Cell[26180, 844, 398, 14, 67, "Text"],
Cell[26581, 860, 332, 7, 57, "NumberedEquation",
  CellTags->"Delta-Momente"],
Cell[26916, 869, 362, 10, 67, "Text"],
Cell[27281, 881, 139, 3, 59, "NumberedEquation",
  CellTags->"Null hoch z"],
Cell[27423, 886, 300, 9, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27760, 900, 243, 11, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[28006, 913, 381, 9, 113, "Text"],
Cell[28390, 924, 916, 29, 136, "Text"],
Cell[29309, 955, 147, 3, 45, "NumberedEquation",
  CellTags->"genaueres Null hoch z"],
Cell[29459, 960, 401, 12, 90, "Text"],
Cell[29863, 974, 674, 22, 113, "Text"],
Cell[30540, 998, 701, 20, 115, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31302, 1025, 151, 6, 75, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[31478, 1035, 145, 7, 67, "Subsection"],

Cell[CellGroupData[{
Cell[31648, 1046, 185, 9, 60, "Subsubsection"],
Cell[31836, 1057, 512, 12, 113, "Text"],
Cell[32351, 1071, 693, 15, 159, "Text"],
Cell[33047, 1088, 552, 10, 159, "Text"],
Cell[33602, 1100, 177, 4, 67, "Text"],
Cell[33782, 1106, 327, 9, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34146, 1120, 213, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[34362, 1132, 284, 7, 90, "Text"],
Cell[34649, 1141, 499, 11, 113, "Text"],
Cell[35151, 1154, 488, 11, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35676, 1170, 195, 9, 60, "Subsubsection"],
Cell[35874, 1181, 414, 8, 113, "Text"],
Cell[36291, 1191, 273, 6, 90, "Text"],
Cell[36567, 1199, 220, 4, 90, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36836, 1209, 167, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[37028, 1221, 215, 9, 60, "Subsubsection"],
Cell[37246, 1232, 215, 6, 67, "Text"],
Cell[37464, 1240, 277, 5, 56, "NumberedEquation",
  CellTags->"Laplace-Transformation der Delta-Funktion"],
Cell[37744, 1247, 600, 17, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38381, 1269, 204, 9, 60, "Subsubsection"],
Cell[38588, 1280, 455, 7, 136, "Text"],
Cell[39046, 1289, 696, 15, 182, "Text"],
Cell[39745, 1306, 418, 8, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40200, 1319, 234, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[40437, 1331, 242, 6, 67, "Text"],
Cell[40682, 1339, 298, 6, 56, "NumberedEquation",
  CellTags->"Laplace-Faltung mit Delta-Funktion"],
Cell[40983, 1347, 653, 16, 167, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41673, 1368, 214, 9, 60, "Subsubsection"],
Cell[41890, 1379, 274, 6, 90, "Text"],
Cell[42167, 1387, 198, 4, 35, "NumberedEquation",
  CellTags->"\[CapitalUDoubleDot]bergang zur Greenschen Funktion"],
Cell[42368, 1393, 412, 8, 113, "Text"],
Cell[42783, 1403, 592, 11, 153, "NumberedEquation",
  CellTags->"Beispiel zur Greenschen Funktion"],
Cell[43378, 1416, 337, 7, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43752, 1428, 234, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[43989, 1440, 233, 4, 90, "Text"],
Cell[44225, 1446, 289, 6, 55, "NumberedEquation",
  CellTags->"Fourier-Faltung"],
Cell[44517, 1454, 499, 11, 113, "Text"],
Cell[45019, 1467, 869, 22, 177, "Text"],
Cell[45891, 1491, 261, 5, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46189, 1501, 239, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[46431, 1513, 335, 7, 90, "Text"],
Cell[46769, 1522, 608, 13, 136, "Text"],
Cell[47380, 1537, 1012, 17, 234, "NumberedEquation",
  CellTags->"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"],
Cell[48395, 1556, 326, 9, 90, "Text"],
Cell[48724, 1567, 330, 9, 90, "Text"],
Cell[49057, 1578, 701, 13, 139, "NumberedEquation",
  CellTags->"diffusions-relevanter Riesz-Operator"],
Cell[49761, 1593, 462, 12, 90, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50284, 1612, 137, 6, 75, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[50446, 1622, 150, 7, 67, "Subsection"],

Cell[CellGroupData[{
Cell[50621, 1633, 209, 9, 60, "Subsubsection"],
Cell[50833, 1644, 566, 11, 136, "Text"],
Cell[51402, 1657, 694, 15, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52133, 1677, 210, 9, 60, "Subsubsection"],
Cell[52346, 1688, 799, 15, 182, "Text"],
Cell[53148, 1705, 854, 20, 159, "Text"],
Cell[54005, 1727, 422, 9, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54464, 1741, 211, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[54678, 1753, 619, 15, 113, "Text"],
Cell[55300, 1770, 415, 11, 90, "Text"],
Cell[55718, 1783, 494, 17, 68, "Text"],
Cell[56215, 1802, 1271, 26, 157, "NumberedEquation",
  CellTags->"Foxsche H-Funktion"],
Cell[57489, 1830, 792, 18, 159, "Text"],
Cell[58284, 1850, 444, 9, 113, "Text"],
Cell[58731, 1861, 522, 8, 159, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[59302, 1875, 197, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[59524, 1887, 181, 9, 60, "Subsubsection"],
Cell[59708, 1898, 357, 6, 113, "Text"],
Cell[60068, 1906, 629, 13, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60734, 1924, 182, 9, 60, "Subsubsection"],
Cell[60919, 1935, 293, 5, 113, "Text"],
Cell[61215, 1942, 249, 7, 67, "Text"],
Cell[61467, 1951, 224, 4, 42, "NumberedEquation",
  CellTags->"Mellin-Laplace-Transformation"],
Cell[61694, 1957, 125, 3, 67, "Text"],
Cell[61822, 1962, 392, 8, 113, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[62263, 1976, 197, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[62485, 1988, 189, 9, 60, "Subsubsection"],
Cell[62677, 1999, 254, 5, 90, "Text"],
Cell[62934, 2006, 695, 15, 159, "Text"],
Cell[63632, 2023, 1570, 33, 241, "NumberedEquation",
  CellTags->"Momente aus Fourier-Transformierter"],
Cell[65205, 2058, 335, 10, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65577, 2073, 203, 9, 60, "Subsubsection"],
Cell[65783, 2084, 179, 4, 67, "Text"],
Cell[65965, 2090, 460, 11, 69, "NumberedEquation",
  CellTags->"Momententheorem"],
Cell[66428, 2103, 410, 11, 90, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66899, 2121, 123, 6, 75, "Section",
  PageBreakAbove->True],
Cell[67025, 2129, 221, 4, 90, "Text"],
Cell[67249, 2135, 300, 5, 113, "Text"],
Cell[67552, 2142, 301, 7, 67, "Text"],
Cell[67856, 2151, 225, 4, 90, "Text"],
Cell[68084, 2157, 329, 6, 113, "Text"],
Cell[68416, 2165, 40, 1, 44, "Text",
  PageBreakAbove->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

